Struct PathAndQuery
pub struct PathAndQuery {
pub(super) data: ByteStr,
pub(super) query: u16,
}Expand description
Represents the path component of a URI
Fields
data: ByteStrquery: u16Implementations
impl PathAndQuery
impl PathAndQuery
pub const fn from_static(src: &'static str) -> PathAndQuery
pub const fn from_static(src: &'static str) -> PathAndQuery
Convert a PathAndQuery from a static string.
This function will not perform any copying, however the string is checked to ensure that it is valid.
Panics
This function panics if the argument is an invalid path and query.
Examples
let v = PathAndQuery::from_static("/hello?world");
assert_eq!(v.path(), "/hello");
assert_eq!(v.query(), Some("world"));Attempt to convert a Bytes buffer to a PathAndQuery.
This will try to prevent a copy if the type passed is the type used internally, and will copy the data if it is not.
pub fn path(&self) -> &str
pub fn path(&self) -> &str
Returns the path component
The path component is case sensitive.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|--------|
|
pathIf the URI is * then the path component is equal to *.
Examples
let path_and_query: PathAndQuery = "/hello/world".parse().unwrap();
assert_eq!(path_and_query.path(), "/hello/world");pub fn query(&self) -> Option<&str>
pub fn query(&self) -> Option<&str>
Returns the query string component
The query component contains non-hierarchical data that, along with data in the path component, serves to identify a resource within the scope of the URIโs scheme and naming authority (if any). The query component is indicated by the first question mark (โ?โ) character and terminated by a number sign (โ#โ) character or by the end of the URI.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-------------------|
|
queryExamples
With a query string component
let path_and_query: PathAndQuery = "/hello/world?key=value&foo=bar".parse().unwrap();
assert_eq!(path_and_query.query(), Some("key=value&foo=bar"));Without a query string component
let path_and_query: PathAndQuery = "/hello/world".parse().unwrap();
assert!(path_and_query.query().is_none());pub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Returns the path and query as a string component.
Examples
With a query string component
let path_and_query: PathAndQuery = "/hello/world?key=value&foo=bar".parse().unwrap();
assert_eq!(path_and_query.as_str(), "/hello/world?key=value&foo=bar");Without a query string component
let path_and_query: PathAndQuery = "/hello/world".parse().unwrap();
assert_eq!(path_and_query.as_str(), "/hello/world");Trait Implementations
impl Clone for PathAndQuery
impl Clone for PathAndQuery
fn clone(&self) -> PathAndQuery
fn clone(&self) -> PathAndQuery
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for PathAndQuery
impl Debug for PathAndQuery
impl Display for PathAndQuery
impl Display for PathAndQuery
impl From<PathAndQuery> for Uri
Convert a PathAndQuery into a Uri.
impl From<PathAndQuery> for Uri
Convert a PathAndQuery into a Uri.
fn from(path_and_query: PathAndQuery) -> Uri
fn from(path_and_query: PathAndQuery) -> Uri
impl FromStr for PathAndQuery
impl FromStr for PathAndQuery
type Err = InvalidUri
type Err = InvalidUri
fn from_str(s: &str) -> Result<PathAndQuery, InvalidUri>
fn from_str(s: &str) -> Result<PathAndQuery, InvalidUri>
s to return a value of this type. Read moreimpl Hash for PathAndQuery
impl Hash for PathAndQuery
impl<'a> PartialEq<&'a str> for PathAndQuery
impl<'a> PartialEq<&'a str> for PathAndQuery
impl<'a> PartialEq<PathAndQuery> for &'a str
impl<'a> PartialEq<PathAndQuery> for &'a str
impl PartialEq<PathAndQuery> for String
impl PartialEq<PathAndQuery> for String
impl PartialEq<PathAndQuery> for str
impl PartialEq<PathAndQuery> for str
impl PartialEq<String> for PathAndQuery
impl PartialEq<String> for PathAndQuery
impl PartialEq<str> for PathAndQuery
impl PartialEq<str> for PathAndQuery
impl PartialEq for PathAndQuery
impl PartialEq for PathAndQuery
impl<'a> PartialOrd<&'a str> for PathAndQuery
impl<'a> PartialOrd<&'a str> for PathAndQuery
impl<'a> PartialOrd<PathAndQuery> for &'a str
impl<'a> PartialOrd<PathAndQuery> for &'a str
impl PartialOrd<PathAndQuery> for String
impl PartialOrd<PathAndQuery> for String
impl PartialOrd<PathAndQuery> for str
impl PartialOrd<PathAndQuery> for str
impl PartialOrd<String> for PathAndQuery
impl PartialOrd<String> for PathAndQuery
impl PartialOrd<str> for PathAndQuery
impl PartialOrd<str> for PathAndQuery
impl PartialOrd for PathAndQuery
impl PartialOrd for PathAndQuery
impl<'a> TryFrom<&'a [u8]> for PathAndQuery
impl<'a> TryFrom<&'a [u8]> for PathAndQuery
type Error = InvalidUri
type Error = InvalidUri
fn try_from(
s: &'a [u8],
) -> Result<PathAndQuery, <PathAndQuery as TryFrom<&'a [u8]>>::Error>
fn try_from( s: &'a [u8], ) -> Result<PathAndQuery, <PathAndQuery as TryFrom<&'a [u8]>>::Error>
impl TryFrom<&String> for PathAndQuery
impl TryFrom<&String> for PathAndQuery
type Error = InvalidUri
type Error = InvalidUri
fn try_from(
s: &String,
) -> Result<PathAndQuery, <PathAndQuery as TryFrom<&String>>::Error>
fn try_from( s: &String, ) -> Result<PathAndQuery, <PathAndQuery as TryFrom<&String>>::Error>
impl<'a> TryFrom<&'a str> for PathAndQuery
impl<'a> TryFrom<&'a str> for PathAndQuery
type Error = InvalidUri
type Error = InvalidUri
fn try_from(
s: &'a str,
) -> Result<PathAndQuery, <PathAndQuery as TryFrom<&'a str>>::Error>
fn try_from( s: &'a str, ) -> Result<PathAndQuery, <PathAndQuery as TryFrom<&'a str>>::Error>
impl TryFrom<String> for PathAndQuery
impl TryFrom<String> for PathAndQuery
type Error = InvalidUri
type Error = InvalidUri
fn try_from(
s: String,
) -> Result<PathAndQuery, <PathAndQuery as TryFrom<String>>::Error>
fn try_from( s: String, ) -> Result<PathAndQuery, <PathAndQuery as TryFrom<String>>::Error>
impl TryFrom<Vec<u8>> for PathAndQuery
impl TryFrom<Vec<u8>> for PathAndQuery
type Error = InvalidUri
type Error = InvalidUri
impl Eq for PathAndQuery